@@ -23,9 +23,10 @@ PPI::Document - Object representation of a Perl document
   $Document->prune('PPI::Token::Comment');
   
   # Find all the named subroutines
-  my @subs = $Document->find( 
+  my $sub_nodes = $Document->find( 
   	sub { $_[1]->isa('PPI::Statement::Sub') and $_[1]->name }
   	);
+  my @sub_names = map { $_->name } @$sub_nodes;
   
   # Save the file
   $Document->save('My/Module.pm.stripped');
@@ -71,7 +72,6 @@ use Params::Util                  '_INSTANCE',
 use Digest::MD5                   ();
 use PPI                           ();
 use PPI::Util                     ();
-use PPI::Document::Fragment       ();
 use PPI::Exception::ParserTimeout ();
 use overload 'bool'               => sub () { 1 };
 use overload '""'                 => 'content';
@@ -81,10 +81,12 @@ use constant HAS_ALARM            => (
 
 use vars qw{$VERSION $errstr};
 BEGIN {
-	$VERSION = '1.202_01';
+	$VERSION = '1.202_03';
 	$errstr  = '';
 }
 
+use PPI::Document::Fragment ();
+
 # Document cache
 my $CACHE = undef;
 
@@ -369,11 +371,11 @@ or write to the file.
 
 sub save {
 	my $self = shift;
-	local *PPIOUTPUT;
-	open( PPIOUTPUT, ">", $_[0] )    or return undef;
-	print PPIOUTPUT $self->serialize or return undef;
-	close PPIOUTPUT                  or return undef;
-	1;
+	local *FILE;
+	open( FILE, '>', $_[0] )    or return undef;
+	print FILE $self->serialize or return undef;
+	close FILE                  or return undef;
+	return 1;
 }
 
 =pod
@@ -832,7 +834,7 @@ L<PPI>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
